recsyslearn.accuracy package
============================

Submodules
----------

recsyslearn.accuracy.metrics module
-----------------------------------

.. automodule:: recsyslearn.accuracy.metrics
   :members:
   :undoc-members:
   :show-inheritance:

recsyslearn.accuracy.utils module
---------------------------------

.. automodule:: recsyslearn.accuracy.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: recsyslearn.accuracy
   :members:
   :undoc-members:
   :show-inheritance:
